@@ -4,6 +4,7 @@ from .app.install.install import Install
 from .app.show.show import Show
 from .app.update.update import Update
 from .config import config
+from .core.entities.actions import Actions
 from .gateways.arg_parser import parse_args
 from .gateways.downloader import Downloader
 from .gateways.jar_parser import JarParser
@@ -19,19 +20,19 @@ def main():
     downloader = Downloader()
     repo = RepoImpl(jar_parser, sqlite, downloader)
     try:
-        if config.action == "update":
+        if config.action == Actions.update:
             update = Update(repo)
             update.execute(config.arg_mods)
 
-        elif config.action == "install":
+        elif config.action == Actions.install:
             install = Install(repo)
             install.execute(config.arg_mods)
 
-        elif config.action == "configure":
+        elif config.action == Actions.configure:
             configure = Configure(repo)
             configure.execute(config.arg_mods)
 
-        elif config.action == "list":
+        elif config.action == Actions.list:
             show = Show(repo)
             show.execute()
     finally:
